#
# spec file for package biboumi
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2018 Tomáš Čech <sleep_walker@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           biboumi
Version:        9.0
Release:        bp154.1.28
Summary:        XMPP to IRC gateway
License:        Zlib
Group:          Productivity/Networking/IRC
URL:            https://biboumi.louiz.org/
Source0:        https://git.louiz.org/biboumi/snapshot/biboumi-%{version}.tar.xz
# PATCH-FEATURE-UPSTREAM do-not-require-git.patch -- Only add git target if file is missing
Patch0:         do-not-require-git.patch
Patch1:         harden_biboumi.service.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libgcrypt-devel
BuildRequires:  pkgconfig
BuildRequires:  udns-devel
BuildRequires:  pkgconfig(botan-2)
BuildRequires:  pkgconfig(catch2)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(libidn)
BuildRequires:  pkgconfig(libpq)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(uuid)

%description
Biboumi is an XMPP gateway that connects to IRC servers and
translates between the two protocols. XMPP users can take part in IRC
discussions, using their favourite XMPP client.

It provides the following features:

 * Connection from an unlimited number of XMPP users to an unlimited number of IRC servers
 * Persistent connections to a configured list of channels, making it behave as an IRC bouncer
 * Basic channel features: join, part, view and set the topic, view and set channel or user modes, kick, nick change…
 * Private conversations
 * Notices
 * Invitations
 * IRC colors (receive only)
 * TLS connections to IRC servers
 * Channel listing
 * CTCP version and ping
 * Dynamic per-user, per-server configuration using XMPP ad-hoc commands and data-forms
 * Automatic sending of a command on connection (mostly used to send an identify message to NickServ or other authentication services)
 * Support for sending arbitrary IRC commands to a server
 * Embedded identd server
 * Message Archive Management support

%prep
%autosetup -p1

%build
%cmake
%cmake_build

%install
%cmake_install
install -m 0755 -d %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}

%check
pushd %{__builddir}
%make_build check
popd

%pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%license COPYING
%doc CHANGELOG.rst README.rst
%dir %{_sysconfdir}/biboumi
%config %{_sysconfdir}/biboumi/*
%{_unitdir}/%{name}.service
%{_bindir}/biboumi
%{_sbindir}/rc%{name}

%changelog
* Wed Aug 11 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s). Added patch(es):
  * harden_biboumi.service.patch
* Sun Apr 18 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 9.0:
  * Messages reflections are now properly cut if the body was cut
    befor being to sent to IRC
  * Messages from unjoined resources are now rejected instead of
    being accepted.
  * All commands sent to IRC servers are now throttled to avoid
    being disconnected for excess flood. The limit value can be
    customized using the ad-hoc configuration form on a server JID.
  * Support for XEP-0410 Self-Ping Optimization.
  * SASL support has been added.
  * SIGHUP is now caught and reloads the configuration like
    SIGUSR1 and 2.
  * Add a verify_certificate policy option that lets the admin
    disable certificate validation per-domain.
  * The WatchdogSec value in the biboumi.service file
    now defaults to the empty string, which means “disabled”.
- Added do-not-require-git.patch, use system Catch2
- Enable tests
* Wed Aug 26 2020 Dirk Mueller <dmueller@suse.com>
- update to 8.5:
  * Fix a build failure with GCC 10
  * Fix a possible crash that could be caused by a very well timed identd query
* Fri Jun  1 2018 benedikt@g5r.eu
- Update to biboumi 8.3
  Changes in version 8.3
  * The global ad-hoc configure command is now available on biboumi’s JID in
  fixed_irc_server mode.
  Changes in version 8.2
  * The users are not able to bypass the fixed mode by just configuring a
  different Address for the IRC server anymore.
  Changes in version 8.1
  * Fix a crash on a raw NAMES command
  Changes in version 8.0
  * GCC 4.9 or lower are not supported anymore. The minimal version is 5.0
  * Add a complete='true' in MAM’s iq result when appropriate
  * The archive ordering now only relies on the value of the ID, not the
  date. This means that if you manually import archives in your database (or
    mess with it somehow), biboumi will not work properly anymore, if you
  don’t make sure the ID of everything in the muclogline table is
  consistent.
  * The “virtual” channel with an empty name (for example
    %%irc.freenode.net@biboumi) has been entirely removed.
  * Add an “Address” field in the servers’ configure form. This lets
  the user customize the address to use when connecting to a server.
  See https://lab.louiz.org/louiz/biboumi/issues/3273 for more details.
  * Messages id are properly reflected to the sender
  * We now properly deal with a PostgreSQL server restart: whenever the
  connection is lost with the server, we try to reconnect and re-execute the
  query once.
  * A Nick field has been added in the IRC server configuration form, to let
  the user force a nickname whenever a channel on the server is joined.
  * Multiple admins can now be listed in the admin field, separated with a colon.
  * Missing fields in a data-form response are now properly interpreted as
  an empty value, and not the default value. Gajim users were not able to
  empty a field of type text-multi because of this issue.
  * Fix an uncaught exception with botan, when policy does not allow any
  available ciphersuite.
  * When the connection gets desynchronized and tries to re-join while
  biboumi thinks it has never left, biboumi now sends the whole standard
  join sequence (history, user-list, etc).
* Fri Mar  9 2018 sleep_walker@opensuse.org
- add license file, add some basic documentation files
* Sun Mar  4 2018 jengelh@inai.de
- Trim redundancies in description.
- Enable parallel build.
* Sun Feb 11 2018 sleep_walker@opensuse.org
- require Botan2 instead of Botan to enable TLS
* Tue Feb  6 2018 sleep_walker@opensuse.org
- let there be biboumi!
